broadcast library
Classes
-
Broadcast<
T> - Broadcast (Single-Producer Multi-Consumer) Ring Channel
-
BroadcastReceiver<
T> -
BroadcastSender<
T> - RecvError
- Base class for receive operation errors.
- RecvErrorCanceled
- Receive operation was canceled before completion.
- RecvErrorDisconnected
- All senders have been closed and no more values will arrive.
- RecvErrorEmpty
- Channel is empty and no values are available.
- RecvErrorFailed
- Receive operation failed due to an unexpected exception.
- RecvErrorTimeout
- Receive operation timed out.
-
RecvOk<
T> - Successfully received a value from the channel.
-
RecvResult<
T> - Result of a channel receive operation.
- SendError
- Base class for send operation errors.
- SendErrorDisconnected
- No active receivers are available to receive the value.
- SendErrorFailed
- Send operation failed due to an unexpected exception.
- SendErrorFull
- Channel buffer is full and cannot accept more values.
- SendErrorTimeout
- Send operation timed out.
- SendOk
- Send operation completed successfully.
- SendResult
- Result types for type-safe channel operations without exceptions.
Enums
Extensions
-
ReceiverDrainX
on Receiver<
T> -
Bulk receiving operations for
Receiver. -
ReceiverForward
on Receiver<
T> -
Forward values from a
Receiverto another endpoint. -
ReceiverTimeoutX
on Receiver<
T> -
Timeout operations for
Receiver. -
RecvResultX
on RecvResult<
T> - Convenient boolean checks and value extraction for RecvResult.
-
SenderBatchX
on Sender<
T> -
Batch sending operations for
Sender. -
SenderForward
on Sender<
T> -
Forward values to this
Senderfrom anotherReceiver. -
SenderRateLimitX
on Sender<
T> -
Rate-limiting operations for
Sender. -
SenderStreamX
on Stream<
T> - Bridge from Dart Streams to channel senders.
-
SenderTimeoutX
on Sender<
T> -
Timeout operations for
Sender. - SendResultX on SendResult
- Convenient boolean checks for SendResult.
-
StreamReceiverX
on KeepAliveReceiver<
T> - Bridge between channels and Dart's Stream ecosystem.
Typedefs
-
BroadcastChannel<
T> = (BroadcastSender< T> , Broadcast<T> ) - A tuple representing a Broadcast channel (Sender, SubscriberFactory).
-
OnDrop<
T> = void Function(T dropped)