ChannelSnapshot class final

Constructors

ChannelSnapshot({int sent = 0, int recv = 0, int dropped = 0, int closed = 0, int trySendOk = 0, int trySendFail = 0, int tryRecvOk = 0, int tryRecvEmpty = 0, double? sendP50, double? sendP95, double? sendP99, double? recvP50, double? recvP95, double? recvP99, int recvFirstNs = 0, int recvLastNs = 0, int sendFirstNs = 0, int sendLastNs = 0})
const
ChannelSnapshot.fromTransferable(Map<Object?, Object?> map)
factory

Properties

closed → int
final
dropped → int
final
dropRate → double
no setter
duration → Duration
no setter
hashCode → int
The hash code for this object.
no setterinherited
nsByOp → double
no setter
recv → int
final
recvAvgLatency → double?
no setter
recvFirstNs → int
final
recvLastNs → int
final
recvOpsPerSec → double
no setter
recvP50 → double?
final
recvP95 → double?
final
recvP99 → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendAvgLatency → double?
no setter
sendFirstNs → int
final
sendLastNs → int
final
sendOpsPerSec → double
no setter
sendP50 → double?
final
sendP95 → double?
final
sendP99 → double?
final
sent → int
final
tryRecvEmpty → int
final
tryRecvEmptyRate → double
no setter
tryRecvOk → int
final
trySendFail → int
final
trySendFailureRate → double
no setter
trySendOk → int
final

Methods

merge(ChannelSnapshot other) → ChannelSnapshot
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toTransferable() → Map<String, Object?>

Operators

operator ==(Object other) → bool
The equality operator.
inherited