mpmc library
Classes
- Mpmc
- MPMC (Multiple-Producer Multiple-Consumer) channels - Maximum flexibility for complex patterns.
-
MpmcReceiver<
T> -
MpmcSender<
T> - RecvError
- Base class for receive operation errors.
- RecvErrorCanceled
- Receive operation was canceled before completion.
- RecvErrorDisconnected
- All senders have been closed and no more values will arrive.
- RecvErrorEmpty
- Channel is empty and no values are available.
- RecvErrorFailed
- Receive operation failed due to an unexpected exception.
- RecvErrorTimeout
- Receive operation timed out.
-
RecvOk<
T> - Successfully received a value from the channel.
-
RecvResult<
T> - Result of a channel receive operation.
- SendError
- Base class for send operation errors.
- SendErrorDisconnected
- No active receivers are available to receive the value.
- SendErrorFailed
- Send operation failed due to an unexpected exception.
- SendErrorFull
- Channel buffer is full and cannot accept more values.
- SendErrorTimeout
- Send operation timed out.
- SendOk
- Send operation completed successfully.
- SendResult
- Result types for type-safe channel operations without exceptions.
Enums
Extensions
-
MpmcChannelX
on MpmcChannel<
T> -
ReceiverDrainX
on Receiver<
T> -
Bulk receiving operations for
Receiver. -
ReceiverTimeoutX
on Receiver<
T> -
Timeout operations for
Receiver. -
RecvResultX
on RecvResult<
T> - Convenient boolean checks and value extraction for RecvResult.
-
SenderBatchX
on Sender<
T> -
Batch sending operations for
Sender. -
SenderRateLimitX
on Sender<
T> -
Rate-limiting operations for
Sender. -
SenderTimeoutX
on Sender<
T> -
Timeout operations for
Sender. - SendResultX on SendResult
- Convenient boolean checks for SendResult.
Typedefs
-
MpmcChannel<
T> = (MpmcSender< T> , MpmcReceiver<T> ) - A tuple representing an MPMC channel (Sender, Receiver).
-
OnDrop<
T> = void Function(T dropped)