MpscSender<T> class
final
- Available extensions
Constructors
-
MpscSender.fromTransferable(Map<
String, Object?> data) -
Reconstructs a remote-only sender from a transferable representation.
factory
Properties
-
buf
→ ChannelBuffer<
T> ? -
The buffer is unused by Sender when using remotePort.
no setterinherited
- channelId → int
-
The local ID of the channel.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSendClosed → bool
-
Whether this handle is closed for sending.
no setter
-
localSendChannel
→ ChannelCore<
T, Object> ? -
Fast path: resolve local channel if in same isolate.
Returns null if this IS the local channel or if remote.
no setterinherited
- metricsId → String?
-
final
- mx → MetricsRecorder
-
no setterinherited
-
remoteConnection
→ FlowControlledRemoteConnection<
T> ? -
no setterinherited
- remotePort → PlatformPort
-
The PlatformPort for remote communication.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendDisconnected → bool
-
Whether the channel's send side is disconnected.
no setterinherited
Methods
-
clone(
) → MpscSender< T> -
close(
) → void -
closeRemote(
) → void -
Closes the remote connection if active and syncs metrics.
inherited
-
debounce(
Duration duration) → Sender< T> -
Available on Sender<
Returns a sender that delays events untilT> , provided by the SenderRateLimitX extensiondurationhas passed since the last event. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
T value) → Future< SendResult> -
inherited
-
sendAll(
Iterable< T> it) → Future<void> -
Available on Sender<
Send all items with backpressure handling.T> , provided by the SenderBatchX extension -
sendTimeout(
T v, Duration d) → Future< SendResult> -
Available on Sender<
Send a value with a timeout to prevent indefinite blocking.T> , provided by the SenderTimeoutX extension -
throttle(
Duration duration) → Sender< T> -
Available on Sender<
Returns a sender that limits the rate of events to at most one everyT> , provided by the SenderRateLimitX extensionduration. -
toString(
) → String -
A string representation of this object.
inherited
-
toTransferable(
) → Map< String, Object?> -
Converts this sender to a platform-agnostic transferable representation.
inherited
-
trySend(
T value) → SendResult -
inherited
-
trySendAll(
Iterable< T> it) → Future<void> -
Available on Sender<
Send all items usingT> , provided by the SenderBatchX extensiontrySendwithout waiting (best-effort).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited