subscribe method
Creates a new subscriber.
If replay is 0 (default), the subscriber starts reading from the next message sent.
If replay > 0, the subscriber attempts to read up to replay past messages (if still available).
Implementation
BroadcastReceiver<T> subscribe({int replay = 0}) {
final core = ChannelRegistry.get(_channelId)! as StandardChannelCore<T>;
return core.attachReceiver((c) => BroadcastReceiver<T>._(
c.id, c.createRemotePort(), _buffer, replay,
metricsId: c.metricsId));
}