RecvErrorTimeout class final
Receive operation timed out.
This occurs when using ReceiverTimeoutX.recvTimeout and no value arrives within the specified duration.
Example:
final result = await rx.recvTimeout(Duration(seconds: 5));
if (result is RecvErrorTimeout) {
print('No data received within ${result.limit}');
}
- Inheritance
-
- Object
- RecvResult<
Never> - RecvError
- RecvErrorTimeout
Constructors
- RecvErrorTimeout(Duration limit)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited