OneShotReceiver<T> class
final
- Available extensions
Constructors
-
OneShotReceiver.fromTransferable(Map<
String, Object?> data) -
Reconstructs a remote-only receiver from a transferable representation.
factory
Properties
-
buf
→ ChannelBuffer<
T> -
Gets the remote buffer, initializing connection via Expando if needed.
no setterinherited
- channelId → int
-
The local ID of the channel.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRecvClosed → bool
-
Whether this handle is closed for receiving.
no setterinherited
-
localRecvChannel
→ ChannelCore<
T, Object> ? -
Fast path: resolve local channel if in same isolate.
no setterinherited
- metricsId → String?
-
no setterinherited
- mx → MetricsRecorder
-
no setterinherited
- recvDisconnected → bool
-
Whether the channel's receive side is disconnected.
no setterinherited
-
remoteConnection
→ FlowControlledRemoteConnection<
T> ? -
no setterinherited
- remotePort → PlatformPort
-
The PlatformPort to communicate with the channel.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
closeRemote(
) → void -
Closes the remote connection if active.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pipeTo(
Sender< T> target, {bool dropWhenFull = false, bool closeTargetOnDone = false, bool closeSourceOnDone = false}) → Future<void> -
Available on Receiver<
Forwards all values from this receiver toT> , provided by the ReceiverForward extensiontarget. -
pipeToReceiver(
Receiver< T> target, {bool dropWhenFull = false, bool closeTargetOnDone = false, bool closeSourceOnDone = false}) → Future<void> -
Available on Receiver<
Forwards all values from this receiver toT> , provided by the ReceiverForward extensiontarget. -
recv(
) → Future< RecvResult< T> > -
inherited
-
recvAll(
{Duration idle = Duration.zero, int? max}) → Future< Iterable< T> > -
Available on Receiver<
Receive multiple values with batching and idle timeout.T> , provided by the ReceiverDrainX extension -
recvCancelable(
) → (Future< RecvResult< , void Function())T> > -
inherited
-
recvTimeout(
Duration d) → Future< RecvResult< T> > -
Available on Receiver<
Receive a value with a timeout to prevent indefinite waiting.T> , provided by the ReceiverTimeoutX extension -
toString(
) → String -
A string representation of this object.
inherited
-
toTransferable(
) → Map< String, Object?> -
Converts this receiver to a platform-agnostic transferable representation.
inherited
-
tryRecv(
) → RecvResult< T> -
inherited
-
tryRecvAll(
{int? max}) → Iterable< T> -
Available on Receiver<
Drain all immediately available values without waiting.T> , provided by the ReceiverDrainX extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited