buf property
Gets the remote buffer, initializing connection via Expando if needed.
Implementation
@override
ChannelBuffer<T> get buf {
// If we have a stored connection in Expando, use its buffer
var conn = _receiverConnections[this] as FlowControlledRemoteConnection<T>?;
if (conn != null) return conn.buffer!;
// Otherwise, create new connection and store it
conn = FlowControlledRemoteConnection<T>.forReceiver(remotePort);
_receiverConnections[this] = conn;
return conn.buffer!;
}